@@ -58,7 +58,7 @@ ggwr <- function(formula, data = list(), coords, bandwidth,
 		Polys <- NULL
 		if (is(fit.points, "SpatialPolygonsDataFrame")) {
 			Polys <- Polygons(fit.points)
-			fit.points <- getSpPPolygonsLabptSlots(fit.points)
+			fit.points <- coordinates(fit.points)
 		} else {
 			griddedObj <- gridded(fit.points)
 			fit.points <- coordinates(fit.points)
@@ -66,6 +66,7 @@ ggwr <- function(formula, data = list(), coords, bandwidth,
 	}
 
 	n <- NROW(fit.points)
+	rownames(fit.points) <- NULL
 	if (is.null(colnames(fit.points))) colnames(fit.points) <- c("x", "y")
 	m <- NCOL(x)
 	if (NROW(x) != NROW(coords))
@@ -122,7 +123,8 @@ ggwr <- function(formula, data = list(), coords, bandwidth,
 	} else {
 		if (!is.null(Polys)) {
 			df <- data.frame(SDF@data)
-			rownames(df) <- getSpPPolygonsIDSlots(Polys)
+			rownames(df) <- sapply(slot(Polys, "polygons"),
+                            function(i) slot(i, "ID"))
 			SDF <- SpatialPolygonsDataFrame(Sr=Polys, data=df)
 		}
 	}
